# InlineResponse20013

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**offset** | **str** | Pagination offset for the next page, null if no more pages | [optional] 
**bases** | [**list[InlineResponse20013Bases]**](InlineResponse20013Bases.md) | List of accessible bases | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

